##----------------------------------------------------------------------
## TEST.POPLARS8.R
## 1. Load poplar data;
## 2. Fit linear models.
##
## Data are annual grqwth increments of young poplar trees.
## Trees are either
## 1. Populus nigra betulifolia (NW Europe 'subspecies'); or
## 2. Populus nigra (with a 'Vereecken' ancestor)
##
## 2020-03-25 Acrocephalus Data Services Ltd
## 2020-04-21 slight changes
##----------------------------------------------------------------------
sink('TEST.POPLARS8.out')
source('LOAD.POPLARS8.R', echo=T)
str(popg)

## ss1 is Populus nigra or P.n.betulifolia (NW Europe 'subspecies')
str(ss1)
print(ss1)

##----------------------------------------------------------------------
## Fit models; first, some lm() models
##
## Check effect of mound on growth of just Populus nigra betulifolia.
## Use only data from 2016 (too few records in other years)
##----------------------------------------------------------------------
g2016.pnb <- subset(g2016, g2016$type == 'P.n.betulifolia')
lm2016.pnb0 <- lm(growth ~ 1, data = g2016.pnb)
lm2016.pnb0
lm2016.pnb1 <- lm(growth ~ mound, data = g2016.pnb)
lm2016.pnb1
summary(lm2016.pnb0)
summary(lm2016.pnb1)
anova(lm2016.pnb0, lm2016.pnb1)
## Conclusion: moundyes increases annual growth by 0.379 metres.

##----------------------------------------------------------------------
## Check for year differences in growth of P.n.betulifolia or P.nigra
## (i.e. same species), using mixed effects model function lme().
## 2016 data show that mound significantly improves growth.
##
## To check year differences, allow only trees (in years) growing in
## mounds. (Some trees were moved, so eventually all were in mounds)
##----------------------------------------------------------------------
ss1m <- subset(ss1, ss1$mound == 'yes')
ss1m
nrow(ss1m)
table(ss1m$year)
by1 <- by(ss1m$growth, list(ss1m$tree), mean)
summary(by1[!is.na(by1)])

## lm() model, ignoring grouping structure
lm1 <- lm(growth ~ yearf, data = ss1m)
lm1
summary(lm1)

##----------------------------------------------------------------------
## nlme models
## Form a groupedData object for this subset, check year differences
##----------------------------------------------------------------------
library(nlme)

ss1m.gd <- groupedData(formula = growth ~ yearf | tree, data = ss1m,
    outer = ~ 1 |sex)
lme1 <- lme(growth ~ yearf, data = ss1m.gd, random = ~ 1 | tree)
lme1
summary(lme1)

## Parameter estimates from lm() and lme() models are same but p-values
## are larger (less significant) for lme model
## Conclusion: growth seems slightly lower in 2018 than other years,
## but difference is not significant
## (2018 was very dry during June and July)

##----------------------------------------------------------------------
## Total growth -- number of years varies, so not directly comparable
##----------------------------------------------------------------------
by(popg$growth, list(popg$tree), sum)

## Total growth recorded for each tree over up to 4 years
by1 <- by(popg$growth, list(popg$tree), sum)
bytemp <- data.frame(tree=names(by1), growth = as.vector(by1),
    years = as.vector(table(popg$tree)))
## Total tree growth sorted in descending order, with number of
## years for which data (of trees in mounds) are available
bytemp[sort.list(-bytemp$growth),]

## Total growth of trees where 4 years' data are available
bytemp.ss <- subset(bytemp, bytemp$years==4)
summary(bytemp.ss$growth)
length(bytemp.ss$growth)     ## sample size, 4 years total

sink()